# condax

[![Docs](https://img.shields.io/badge/docs-mkdocs-informational)](https://mariusvniekerk.github.io/condax/)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/mariusvniekerk/condax/Python%20package)](https://github.com/mariusvniekerk/condax/actions?query=workflow%3A%22Python+package%22)
[![Licence: MIT](https://img.shields.io/github/license/mariusvniekerk/condax)](https://github.com/mariusvniekerk/condax/blob/master/LICENSE-MIT)
[![PyPI](https://img.shields.io/pypi/v/condax)](https://pypi.org/project/condax)
[![code-style Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://https://github.com/psf/black)


Condax is inpired by the excellent [pipx](https://github.com/pipxproject/pipx), and attempts to do something similar, just using conda thus lifting the constraints of only packaging python things.

## Installation

condax is distributed on [PyPI](https://pypi.org) as a universal
wheel and is available on Linux and macOS and supports
Python 3.5+ and PyPy.

```bash
$ pip install condax
```

## License

condax is distributed under the terms of the
[MIT License](https://choosealicense.com/licenses/mit).
